@@ -6,14 +6,11 @@ from types import FunctionType
 from werkzeug.exceptions import NotFound
 from werkzeug.routing import Map, Rule
 
-from .context import AppContext
-from .http import HttpServerError, HttpNotFound, HttpRequest
-from .plugins import PluginBase
-from .routes.api_page import ApiPage
-from .routes.router import Router
+from .routes import Collector
+from .util.event import Event
 
 
-class App:
+class App(Event):
     # APP 实例集合
     _APPS = {}
 
@@ -44,7 +41,15 @@ class App:
         :param api_page_cache: 是否缓存接口数据
         :param api_page_addition: 接口页面上要展示的接口的附加信息函数，其接收一个 dict 类型的参数 route_info
         """
+        from .context import AppContext
+        from .routes import ApiPage
+        from .routes import Router
+        from .util import Logger
+
         self.id = app_id or str(uuid.uuid4())
+        self._logger = Logger(app_id)
+
+        sys.excepthook = self._except_hook
 
         self._APPS[self.id] = self
 
@@ -57,21 +62,28 @@ class App:
         self._api_page = ApiPage(self.context)
 
         self._custom_url_map = {}
-        # 请求勾子
-        self._plugins = []
 
         self._url_map = Map([
             Rule('/%s%s' % (api_prefix, '/' if append_slash else ''), endpoint='_api_page'),
             Rule('/%s/<path:entry>%s' % (api_prefix, '/' if append_slash else ''), endpoint='entry_only')
         ])
 
+        Collector.create(app_id, app_root, append_slash)
+
+        super(App, self).__init__()
+
+    def _except_hook(self, except_type, except_value, except_traceback):
+        self._logger.error('%s: %s' % (repr(except_value), repr(except_traceback)))
+
     def __del__(self):
+        self.emit('shutdown')
+
+        self._logger.info('App "%s" is shutting down' % self.id)
+        Collector.destroy(self.id)
+
         if self.id in self._APPS:
             del self._APPS[self.id]
 
-        for plugin in self._plugins:
-            plugin.dispose()
-
     def handle_wsgi_request(self, environ, start_response):
         """
         接收并处理来自 wsgi 的请求
@@ -79,13 +91,14 @@ class App:
         :param start_response:
         :return:
         """
+        from .http import HttpServerError, HttpNotFound, HttpRequest
+
         request = None
         response = None
         try:
             request = HttpRequest(environ, self.context.app_id)
 
-            for plugin in self._plugins:
-                plugin.requesting(request)
+            self.emit('requesting', request=request)
 
             adapter = self._url_map.bind_to_environ(environ)
 
@@ -102,17 +115,16 @@ class App:
             if isinstance(e, NotFound):
                 response = HttpNotFound()
             elif self.context.debug:
-                raise e
+                response = HttpServerError(e)
             else:
                 response = HttpServerError()
 
-            msg = repr(e)
+            msg = str(e)
             if request:
                 msg += ':' + request.path
-            self.context.logger.warning(msg)
+            self._logger.warning(msg)
         finally:
-            for plugin in reversed(self._plugins):
-                plugin.requested(request, response)
+            self.emit('requested', request=request, response=response)
         return response(environ, start_response)
 
     def __call__(self, environ, start_response):
@@ -153,7 +165,7 @@ class App:
         if len(argv) > 1:
             server_arg = argv[1].split(':')
             if len(server_arg) == 1:
-                self.context.logger.warning('Invalid startup argument "%s" (ignored):' % argv[1])
+                self._logger.warning('Invalid startup argument "%s" (ignored):' % argv[1])
             else:
                 host = server_arg[0]
                 port = int(server_arg[1])
@@ -171,7 +183,7 @@ class App:
         if host in [None, '', '*']:
             host = '0.0.0.0'
 
-        if self.context.api_page_enabled:
+        if self.context.api_page_options['api_page_enabled']:
             if host == '0.0.0.0':
                 from .util import utils
                 ips = utils.get_ip_list()
@@ -192,15 +204,16 @@ class App:
         :param types:
         :return:
         """
+        collector = Collector.get(self.id)
         for type_item in types:
-            self.context.collector.global_types[type_item.__name__] = type_item
+            collector.global_types[type_item.__name__] = type_item
 
     def collect(self):
         """
         收集路由
         :return:
         """
-        return self.context.collector.collect(self.context.routes_map)
+        return Collector.get(self.id).collect(self.context.routes_map)
 
     def persist(self, filename: str = '', encoding='utf8'):
         """
@@ -209,7 +222,7 @@ class App:
         :param encoding:
         :return:
         """
-        return self.context.collector.persist(self.context.routes_map, filename, encoding)
+        return Collector.get(self.id).persist(self.context.routes_map, filename, encoding)
 
     def set_logger(self, logger):
         """
@@ -217,7 +230,7 @@ class App:
         :param logger:
         :return:
         """
-        self.context.logger.custom_logger = logger
+        self._logger.custom_logger = logger
         return self
 
     def map_urls(self, urls_map: dict):
@@ -243,7 +256,7 @@ class App:
             pkg = routes_map[path]
             pkg_path = os.path.join(self.context.ROOT, pkg.replace('.', '/'))
             if not os.path.exists(pkg_path):
-                self.context.logger.warning('Route map "%s" not exists, path=%s' % (pkg, pkg_path))
+                self._logger.warning('Route map "%s" does not exist, path=%s' % (pkg, pkg_path))
             self.context.routes_map[path] = pkg
         return self
 
@@ -256,11 +269,11 @@ class App:
         for prefix in static_map:
             # 静态资源的前缀，必须以 / 开头
             if prefix[0] != '/':
-                self.context.logger.warning(
+                self._logger.warning(
                     'Invalid prefix of static map, it should start with "/": %s' % prefix)
                 continue
             if prefix.lower() == '/internal_assets':
-                self.context.logger.warning(
+                self._logger.warning(
                     'The prefix of static map is reserved, pick another one please: %s' % prefix)
                 continue
             target_path = static_map[prefix]
@@ -268,9 +281,9 @@ class App:
             # 无论目录是否存在都注册，因为静态目录可能是动态生成的
             self.context.static_map[prefix] = abs_target_path
             if os.path.exists(abs_target_path):
-                self.context.logger.debug('Map static url %s to path %s' % (prefix, abs_target_path))
+                self._logger.debug('Map static url %s to path %s' % (prefix, abs_target_path))
             else:
-                self.context.logger.warning(
+                self._logger.warning(
                     'The target path of static url %s not found: %s' % (prefix, abs_target_path))
         return self
 
@@ -296,7 +309,7 @@ class App:
 
         rid = '%s#%s' % (path, method.lower())
         if rid in self._router.production_routes:
-            self.context.logger.warning('%s %s exists' % (method, path))
+            self._logger.warning('Duplicated route %s %s' % (method, path))
 
         desc = FunctionDescription(handler)
         self._router.production_routes[rid] = {
@@ -316,17 +329,14 @@ class App:
         for middleware in middlewares:
             assert isinstance(middleware, MiddlewareBase)
             self.context.middlewares.append(middleware)
-            self.context.reversed_middlwares.insert(0, middleware)
+            self.context.reversed_middlewares.insert(0, middleware)
+            middleware.late_init(self)
         return self
 
     def inject(self, **kwargs):
         self.context.injections.update(**kwargs)
         return self
 
-    def register_plugin(self, *plugins: PluginBase):
-        self._plugins += plugins
-        return self
-
     @classmethod
     def get(cls, app_id: str):
         """
