@@ -52,11 +52,12 @@ class FileResponse(HttpResponse):
             kwargs['headers'] = headers
 
         if not request:
-            print(
-                'You are using FileReponse for attachment,'
-                'it is recommanded to fill the "request" parameter.'
-                'Otherwise, you may got an encoding issue of the filename.'
-            )
+            from ..util import Logger
+            Logger.print('warning',
+                         'You are using FileResponse for attachment,'
+                         'it is recommended to fill the "request" parameter.'
+                         'Otherwise, you may got an encoding issue of the filename.'
+                         )
 
         user_agent = request and request.headers.environ['HTTP_USER_AGENT']
         is_firefox = user_agent and ('Firefox/' in user_agent)
@@ -93,9 +94,7 @@ class HttpNotFound(HttpResponse):
 
 
 class HttpServerError(HttpResponse, InternalServerError):
-    def __init__(self, content=None, **kwargs):
-        e = None
+    def __init__(self, content=None):
         if isinstance(content, Exception):
-            e = content
-            content = None
-        super().__init__(content, None, e, **kwargs)
+            content = str(content)
+        super().__init__(content, status=500, content_type='text/plain')
