@@ -1,30 +1,39 @@
+import re
+
+from restfx.util import utils
+
+
 class Logger:
+    _LOGGERS = {}
     colors = {
         'error': '\033[1;31m',
         'warning': '\033[1;33m',
         'debug': '\033[1;37m'
     }
 
-    def __init__(self, debug_mode: bool):
-        self.debug_mode = debug_mode
+    def __init__(self, app_id: str):
+        self.app_id = app_id
+        self._LOGGERS[app_id] = self
         self.custom_logger = None
 
+    @classmethod
+    def print(cls, level, message):
+
+        if level not in cls.colors:
+            print('%s' % message)
+            return
+
+        print('%s%s%s' % (cls.colors[level], message, '\033[0m'))
+
     def log(self, level, message, e=None):
         if self.custom_logger is not None:
             # noinspection PyUnresolvedReferences
             self.custom_logger(level, message, e)
             return
-
-        if level not in self.colors:
-            print('[%s] %s' % (level, message))
-            return
-
-        print('%s[%s] %s%s' % (self.colors[level], level, message, '\033[0m'))
+        self.print(level, message)
 
     def debug(self, message):
-        # 仅在 debug 模式下输出这类日志
-        if self.debug_mode:
-            self.log('debug', message)
+        self.log('debug', message)
 
     def info(self, message):
         self.log('info', message)
@@ -33,11 +42,11 @@ class Logger:
         self.log('warning', message)
 
     def error(self, message, e=None, _raise=True):
-        temp = message if e is None else '%s\n\t%s' % (message, repr(e))
+        temp = utils.get_exception_info(message, e)
 
         # 非开发模式时，始终不会输出堆栈信息
         if not self.debug:
-            self.log('ERROR', temp, e)
+            self.log('error', temp, e)
             return
 
         # print('\033[1;31;47m {0} \033[0m'.format(temp))
@@ -46,7 +55,7 @@ class Logger:
 
         # 不需要抛出异常
         if not _raise:
-            self.log('ERROR', temp, e)
+            self.log('error', temp, e)
             return
 
         # 抛出新的异常
@@ -54,6 +63,19 @@ class Logger:
             raise Exception(message)
 
         # 修改异常消息
-        new_msg = '%s\n\t%s' % (message, e.args[0]) if len(e.args) > 0 else message
-        e.args = (new_msg,)
+        # new_msg = '%s\n\t%s' % (temp, e.args[0]) if len(e.args) > 0 else temp
+        e.args = (temp,)
+        e.msg = temp
         raise e
+
+    @classmethod
+    def remove(cls, app_id: str):
+        if app_id in cls._LOGGERS:
+            del cls._LOGGERS[app_id]
+
+    @classmethod
+    def get(cls, app_id: str):
+        logger = cls._LOGGERS.get(app_id, None)
+        if logger is None:
+            logger = Logger(app_id)
+        return logger
